@@ -89,30 +89,31 @@ BEGIN {
 sub new {
   my ($that,%args) = @_;
   my @connect_args = grep {exists $args{$_}} map {($_,lc($_),uc($_))} qw(Peer PeerAddr PeerPort Url);
-  my %connect = (
-		 ##-- connection options
-		 Domain=>'INET',
-		 PeerAddr=>'localhost',
-		 PeerPort=>50000,
-		 Proto=>'tcp',
-		 Type=>SOCK_STREAM,
-		 Blocking=>1,
+  my $connect = $that->parseAddr
+    ({
+      ##-- connect: default options
+      Domain=>'INET',
+      PeerAddr=>'localhost',
+      PeerPort=>50000,
+      Proto=>'tcp',
+      Type=>SOCK_STREAM,
+      Blocking=>1,
 
-		 ##-- connect: user args
-		 (ref($args{'connect'})
-		  ? %{$args{'connect'}}
-		  : ($args{connect}
-		     ? %{$that->parseAddr($args{connect})}
-		     : qw())),
+      ##-- connect: user args
+      (ref($args{'connect'})
+       ? %{$args{'connect'}}
+       : ($args{connect}
+	  ? %{$that->parseAddr($args{connect})}
+	  : qw())),
 
-		 ##-- connect: top-level args
-		 (map {($_=>$args{$_})} @connect_args),
-		);
+      ##-- connect: top-level args
+      (map {($_=>$args{$_})} @connect_args),
+     });
   delete @args{'connect',@connect_args};
 
   my $dc =bless {
 		 ##-- connection options
-		 connect=>\%connect,
+		 connect=> $connect,
 		 linger => [1,0],
 		 mode   =>'json',
 		 encoding => 'UTF-8',
